@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -51,9 +52,13 @@ using namespace com::sun::star::uno;
 using namespace com::sun::star::beans;
 using namespace com::sun::star::container;
 using namespace com::sun::star::reflection;
-using namespace rtl;
 using namespace codemaker;
 
+using ::rtl::OUString;
+using ::rtl::OString;
+using ::rtl::OStringToOUString;
+using ::rtl::OUStringToOString;
+
 namespace unodevtools {
 
 void writeConstantData(typereg::Writer& rWriter, sal_uInt16 fieldIndex,
@@ -131,7 +136,7 @@ void writeConstantData(typereg::Writer& rWriter, sal_uInt16 fieldIndex,
     }
     break;
     default:
-        OSL_ENSURE( 0, "unsupported constant type" );
+        OSL_FAIL( "unsupported constant type" );
         break;
     }
     
@@ -793,7 +798,7 @@ void* getTypeBlob(Reference< XHierarchicalNameAccess > xTDmgr,
     }
     break;
     default:
-        OSL_ENSURE( 0, "unsupported type" );
+        OSL_FAIL( "unsupported type" );
         break;
     }
     
@@ -801,3 +806,5 @@ void* getTypeBlob(Reference< XHierarchicalNameAccess > xTDmgr,
 }	
 
 } // end of namespace unodevtools
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
